//
//  UIAlertController+showAlertOnMainThread.m
//  Socket Protocol
//
//  Created by 黄 庆超 on 2016/10/31.
//  Copyright © 2016年 com.hqc. All rights reserved.
//

#import "UIAlertController+showAlertOnMainThread.h"

@implementation UIAlertController (showAlertOnMainThread)

__weak  UIAlertController   *_alertController;

+(UIAlertController * _Nonnull)showHintAlertOnMainThreadWithMsg:(NSString *)msg{
    return [self showHintAlertOnMainThreadWithTitle:nil withMsg:msg completion:nil];
}

+(UIAlertController * _Nonnull)showHintAlertOnMainThreadWithTitle:(NSString *)title withMsg:(NSString *)msg completion:(AlertBlock)block{
    return [self showHintAlertOnMainThreadWithTitle:title withMsg:msg withConfirmBtnTitle:NSLocalizedString(@"Okay, got it", @"button title") withConfirmBtnAction:block];
}

+ (UIAlertController * _Nonnull)showHintAlertOnMainThreadWithTitle:(NSString *)title withMsg:(NSString *)msg withConfirmBtnTitle:(NSString *)confirmBtnTitle withConfirmBtnAction:(AlertBlock)confirmBtnAction {
    return [self showHintAlertOnMainThreadWithTitle:title withMsg:msg withTextFieldNum:0 withConfirmBtnTitle:confirmBtnTitle withConfirmBtnAction:confirmBtnAction withCancelBtnTitle:nil withCancelBtnAction:nil];
}

+ (UIAlertController * _Nonnull)showHintAlertOnMainThreadWithTitle:(NSString *)title withMsg:(NSString *)msg withTextFieldNum:(NSUInteger)textFieldNum withConfirmBtnTitle:(NSString *)confirmBtnTitle withConfirmBtnAction:(AlertBlock)confirmBtnAction withCancelBtnTitle:(NSString *)cancelBtnTitle withCancelBtnAction:(AlertBlock)cancelBtnAction {
    
    __block UIAlertController *alertController;
    [[NSOperationQueue mainQueue] addOperationWithBlock:^{
        alertController = [UIAlertController alertControllerWithTitle:title message:msg preferredStyle:UIAlertControllerStyleAlert];
        
        for (NSUInteger i = 0; i < textFieldNum; i++) {
            [alertController addTextFieldWithConfigurationHandler:nil];
        }
        
        if (confirmBtnTitle) {
            UIAlertAction *confirmAction = [UIAlertAction actionWithTitle:confirmBtnTitle style:UIAlertActionStyleDefault handler:^(UIAlertAction * _Nonnull action) {
                if (confirmBtnAction) {
                    confirmBtnAction(alertController);
                }
            }];
            [alertController addAction:confirmAction];
        }
        
        if (cancelBtnTitle.length) {
            UIAlertAction *cancelAction = [UIAlertAction actionWithTitle:cancelBtnTitle style:UIAlertActionStyleDefault handler:^(UIAlertAction * _Nonnull action) {
                if (cancelBtnAction) {
                    cancelBtnAction(alertController);
                }
            }];
            [alertController addAction:cancelAction];
        }
        
        UIWindow *window = [[UIWindow alloc] initWithFrame:[UIScreen mainScreen].bounds];
        [window setRootViewController:[[UIViewController alloc] init]];
        window.windowLevel = UIWindowLevelAlert;
        [window makeKeyAndVisible];
        
//        [window.rootViewController presentViewController:alertController animated:YES completion:nil];
        
    }];
    return alertController;
}

+ (UIAlertController *)offlineTipsWithCompletion:(void (^)(void))completion {
    NSString *title = NSLocalizedString(@"Notice", @"show text");
    NSString *message = NSLocalizedString(@"Your network is offline, please check your network", @"Alert controller description for an offline network");
    NSString *buttonTitle = NSLocalizedString(@"OK", @"OK");

    UIAlertController *alertController = [self alertControllerWithTitle:title message:message preferredStyle:UIAlertControllerStyleAlert];
    UIAlertAction *okAction = [UIAlertAction actionWithTitle:buttonTitle style:UIAlertActionStyleDefault handler:^(UIAlertAction * _Nonnull action) {
        if (completion) {
            completion();
        }
    }];
    [alertController addAction:okAction];
    alertController.preferredAction = okAction;
    return alertController;
}

@end

